==> jc-1.4.0.tar.gz: soot/jimple/internal/AbstractJimpleIntBinopExpr.h <==
// public abstract class soot.jimple.internal.AbstractJimpleIntBinopExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class f9eab9f2510f54c9 soot_jimple_internal_AbstractIntBinopExpr
// @dep_class 742ef0012b237efb soot_jimple_internal_AbstractJimpleIntBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractIntBinopExpr

#include "soot/jimple/internal/AbstractIntBinopExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractJimpleIntBinopExpr_H_
#define _JC_soot_jimple_internal_AbstractJimpleIntBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_refs	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$refs	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$nonrefs	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vmethods	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtable	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtype	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$method_info$convertToBaf$0357e46cf55b475a;
extern _jc_method _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vmethods {
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntBinopExpr$vmethods	soot_jimple_internal_AbstractIntBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleIntBinopExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$refs {
    _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleIntBinopExpr;
    _jc_soot_jimple_internal_AbstractIntBinopExpr$sub_refs	soot_jimple_internal_AbstractIntBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleIntBinopExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object {
	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtype _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractJimpleIntBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractJimpleIntBinopExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/AbstractJimpleIntBinopExpr.h <==
// public abstract class soot.jimple.internal.AbstractJimpleIntBinopExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class f9eab9f2510f54c9 soot_jimple_internal_AbstractIntBinopExpr
// @dep_class 742ef0012b237efb soot_jimple_internal_AbstractJimpleIntBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractIntBinopExpr

#include "soot/jimple/internal/AbstractIntBinopExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractJimpleIntBinopExpr_H_
#define _JC_soot_jimple_internal_AbstractJimpleIntBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_jimple_JimpleToBafContext$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_refs	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$refs	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$nonrefs	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vmethods	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtable	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtype	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$method$convertToBaf$0357e46cf55b475a(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$method_info$convertToBaf$0357e46cf55b475a;
extern _jc_method _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vmethods {
	void	(*convertToBaf$0357e46cf55b475a)(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object *, struct _jc_soot_jimple_JimpleToBafContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntBinopExpr$vmethods	soot_jimple_internal_AbstractIntBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleIntBinopExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$refs {
    _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleIntBinopExpr;
    _jc_soot_jimple_internal_AbstractIntBinopExpr$sub_refs	soot_jimple_internal_AbstractIntBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleIntBinopExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$object {
	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$vtype _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractJimpleIntBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractJimpleIntBinopExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractJimpleIntBinopExpr_H_ */
